<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>BitcoinButton</name>
    <message>
        <location filename="../BitcoinButton.qml" line="34"/>
        <source>Bitcoin address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="111"/>
        <source>Copy address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="116"/>
        <source>Bitcoin address copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DonationDialog</name>
    <message>
        <location filename="../DonationDialog.qml" line="8"/>
        <source>Choose a donation method:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelector</name>
    <message>
        <location filename="../FileSelector.qml" line="14"/>
        <source>File Selector</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FlattrButton</name>
    <message>
        <location filename="../FlattrButton.qml" line="25"/>
        <source>Opening &lt;b&gt;Flattr&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryPage</name>
    <message>
        <location filename="../HistoryPage.qml" line="20"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="31"/>
        <location filename="../HistoryPage.qml" line="118"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Do not delete items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Delete items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="57"/>
        <source>Select items to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="61"/>
        <location filename="../HistoryPage.qml" line="115"/>
        <source>Erase history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="74"/>
        <source>no entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="116"/>
        <source>Do you want to erase the history of all mangas and comic books opened by Mieru?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="117"/>
        <source>Erase</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InfoPage</name>
    <message>
        <location filename="../InfoPage.qml" line="14"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="18"/>
        <source>Stats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="22"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="77"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="80"/>
        <source>Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="83"/>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="91"/>
        <source>Online search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="97"/>
        <source>Opening &lt;b&gt;Google&lt;/b&gt; search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="106"/>
        <source>Opening &lt;b&gt;Wikipedia&lt;/b&gt; search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="115"/>
        <source>Opening &lt;b&gt;Manga updates&lt;/b&gt; search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="132"/>
        <source>Usage Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="162"/>
        <location filename="../InfoPage.qml" line="271"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="207"/>
        <source>Mieru is a flexible Manga and comic book reader.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="243"/>
        <source>main developer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="246"/>
        <source>email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="250"/>
        <source>www</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="255"/>
        <source>discussion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="269"/>
        <source>Reset all usage statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="270"/>
        <source>Do you really want to reset all usage statistics?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="272"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../MainView.qml" line="169"/>
        <source>original</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="171"/>
        <source>width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="173"/>
        <source>height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="175"/>
        <source>screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="177"/>
        <source>orient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="184"/>
        <source>most</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="192"/>
        <source>custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="250"/>
        <source>Open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="257"/>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="261"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="265"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="272"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="504"/>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="524"/>
        <source>No pages loaded</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsPage</name>
    <message>
        <location filename="../OptionsPage.qml" line="29"/>
        <source>Page view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="32"/>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="47"/>
        <source>auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="55"/>
        <source>portrait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="63"/>
        <source>landscape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="71"/>
        <source>Show status bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="79"/>
        <source>Remember toolbar state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="86"/>
        <source>Fullscreen button opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="112"/>
        <source>Paging options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="115"/>
        <source>Paging mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="130"/>
        <source>Whole screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="138"/>
        <source>On edges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="148"/>
        <source>Middle click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="158"/>
        <source>Middle doubleclick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="168"/>
        <source>Show paging feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="178"/>
        <source>Page scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="181"/>
        <source>Page fit mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="190"/>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="193"/>
        <source>history enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="201"/>
        <source>use when opening files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="210"/>
        <source>Miscellaneous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="213"/>
        <source>Manga reading mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="221"/>
        <source>Show release notes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageFitSelector</name>
    <message>
        <location filename="../PageFitSelector.qml" line="10"/>
        <source>Page fit mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="19"/>
        <source>&lt;b&gt;1:1&lt;/b&gt; - original size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="20"/>
        <source>&lt;b&gt;fit to width&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="21"/>
        <source>&lt;b&gt;fit to height&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="22"/>
        <source>&lt;b&gt;fit to screen&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="23"/>
        <source>&lt;b&gt;custom&lt;/b&gt; - remember scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="24"/>
        <source>&lt;b&gt;orientation&lt;/b&gt; specific</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="25"/>
        <source>&lt;b&gt;show the most&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="30"/>
        <source>&lt;b&gt;no action&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PayPalButton</name>
    <message>
        <location filename="../PayPalButton.qml" line="24"/>
        <source>Opening &lt;b&gt;PayPal&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WhatsNewDialog</name>
    <message>
        <location filename="../WhatsNewDialog.qml" line="35"/>
        <source>Opening link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="48"/>
        <source>&lt;b&gt;Do you like Mieru ? Donate !&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="56"/>
        <source>How to donate ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="67"/>
        <source>Don&apos;t show again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="96"/>
        <source>How to turn pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="97"/>
        <source>Tap the &lt;b&gt;right half&lt;/b&gt; of the screen to go to the &lt;b&gt;next page&lt;/b&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="98"/>
        <source>Tap the &lt;b&gt;left half&lt;/b&gt; to go to the &lt;b&gt;previous page&lt;/b&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="99"/>
        <source>Don&apos;t show again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="100"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
